@@ -510,12 +510,50 @@ ryuhei@secondbrain.co.jp
 
     default:
       // ̡̾ʥƥ꡼
+      if ($current_category_id) {
+        // ʬʹ
+        $current_category_query = tep_db_query("select c.categories_id, cd.categories_name, c.categories_image, c.parent_id, c.sort_order, c.date_added, c.last_modified, cd.categories_description, cd.categories_keywords from " . TABLE_CATEGORIES . " c, " . TABLE_CATEGORIES_DESCRIPTION . " cd where c.categories_id = '" . $current_category_id . "' and c.categories_id = cd.categories_id and cd.language_id = '" . $languages_id . "' order by c.sort_order, cd.categories_name");
+        $current_category = tep_db_fetch_array($current_category_query);
+        $current_category_name = $current_category['categories_name'];
+        $category_heading_title = HEADING_TITLE . '&nbsp;&nbsp;' . $current_category_id . '&nbsp;:&nbsp;' . $current_category_name;
+        $current_category_description = $current_category['categories_description'];
+        if ($current_category['categories_image']) {
+          $current_category_image = tep_image(DIR_WS_CATALOG_IMAGES . $current_category['categories_image'], $current_category['categories_name'], HEADING_IMAGE_WIDTH, HEADING_IMAGE_HEIGHT, 'hspace="5" vspace="5"');
+        } else {
+          $current_category_image = '';
+        }
+        $current_category_keywords = $current_category['categories_keywords'];
+        $current_category_date_added = TABLE_HEADING_DATE_ADDED . $current_category['date_added'];
+        if ($current_category['last_modified']) {
+          $current_category_last_modified = TABLE_HEADING_LAST_MODIFIED . $current_category['last_modified'];
+        } else {
+          $current_category_last_modified = '';
+        }
+      } else {
+        // ʬ
+        $current_category_name = TEXT_TOP_CATEGORY;
+        $category_heading_title = HEADING_TITLE . '&nbsp;&nbsp;' . $current_category_name;
+        $current_category_description = '';
+        $current_category_image = '';
+        $current_category_keywords = '';
+        $current_category_date_added = '';
+        $current_category_last_modified = '';
+      }
 ?>
       <tr>
-        <td><table border="0" width="100%" cellspacing="0" cellpadding="0">
+        <td><table border="0" width="100%" cellspacing="0" cellpadding="2">
           <tr>
-            <td class="pageHeading"><?php echo HEADING_TITLE . '&nbsp;&nbsp;' . tep_get_category_name($current_category_id, $languages_id); ?></td>
-            <td align="right" class="smallText"><?php echo tep_draw_form('new_category_check', FILENAME_CATEGORIES_EDIT, 'cPath=' . $cPath . '&action=new_category_check', 'post') . TEXT_CATEGORIES_ID . '&nbsp;' . tep_draw_input_field('categories_id', '', 'size="5"') . tep_image_submit('button_new_category.gif', IMAGE_NEW_CATEGORY, 'align="top"') . '</form>'; ?></td>
+            <td class="pageHeading" colspan="2"><?php echo $category_heading_title; ?></td>
+          </tr>
+          <tr>
+            <td class="dataTableContent" valign="top"><?php echo $current_category_description; ?></td>
+            <td class="dataTableContent"><?php echo $current_category_image; ?></td>
+          </tr>
+          <tr>
+            <td class="dataTableContent" colspan="2"><font color="#FF0000"><?php echo $current_category_keywords; ?></font></td>
+          </tr>
+          <tr>
+            <td class="dataTableContent" colspan="2" align="right"><?php echo $current_category_date_added . "&nbsp;" . $current_category_last_modified; ?></td>
           </tr>
         </table></td>
       </tr>
@@ -525,58 +563,47 @@ ryuhei@secondbrain.co.jp
       <tr>
         <td><table border="0" width="100%" cellspacing="0" cellpadding="0">
           <tr>
-            <td valign="top"><table border="0" width="100%" cellspacing="0" cellpadding="2">
+            <td><table border="0" width="100%" cellspacing="0" cellpadding="0">
+              <tr><?php echo tep_draw_form('new_category_check', FILENAME_CATEGORIES_EDIT, 'cPath=' . $cPath . '&action=new_category_check', 'post'); ?>
+                <td class="smallText"><?php echo $current_category_name . TEXT_CREATE_NEW_CATEGORY; ?></td>
+                <td align="right" class="smallText" nowrap><?php echo TEXT_CATEGORIES_ID . '&nbsp;' . tep_draw_input_field('categories_id', '', 'size="5"') . tep_image_submit('button_new_category.gif', IMAGE_NEW_CATEGORY, 'align="top"'); ?></td>
+              </form></tr>
+            </table></td>
+          </tr>
+          <tr>
+            <td valign="top"><table border="1" width="100%" cellspacing="0" cellpadding="2">
               <tr class="dataTableHeadingRow">
-                <td class="dataTableHeadingContent"><?php echo TABLE_HEADING_CATEGORIES_IMAGES; ?></td>
-                <td class="dataTableHeadingContent"><?php echo TABLE_HEADING_CONTENTS; ?></td>
-                <td class="dataTableHeadingContent" align="right"><?php echo TABLE_HEADING_ACTION; ?>&nbsp;</td>
+                <td class="dataTableHeadingContent" width="10%"><?php echo TABLE_HEADING_CATEGORIES_ID; ?></td>
+                <td class="dataTableHeadingContent" width="45%"><?php echo TABLE_HEADING_CATEGORIES_NAME; ?></td>
+                <td class="dataTableHeadingContent" width="30%"><?php echo TABLE_HEADING_SUB_CATEGORIES_PRODUCTS; ?></td>
+                <td class="dataTableHeadingContent" width="10%" align="right"><?php echo TABLE_HEADING_ACTION; ?>&nbsp;</td>
+                <td class="dataTableHeadingContent" width="5%" align="right" nowrap><?php echo TABLE_HEADING_SORT_ORDER; ?></td>
               </tr>
 <?php
       if (sizeof($cInfo_array) > 0) {
         for ($i = 0, $n = sizeof($cInfo_array); $i < $n; $i++) {
           echo '              <tr class="dataTableRow">' . "\n";
-          echo '                <td class="dataTableContent">';
-          if ($cInfo_array[$i]['categories_image']) {
-            echo tep_image(DIR_WS_CATALOG_IMAGES . $cInfo_array[$i]['categories_image'], $cInfo_array[$i]['categories_name'], HEADING_IMAGE_WIDTH, HEADING_IMAGE_HEIGHT, 'hspace="5" vspace="5"');
-          } else {
-            echo TEXT_NO_IMAGES;
-          }
-          echo "</td>\n";
-          echo '                <td><table border="0" width="100%" cellspacing="0" cellpadding="0">' . "\n";
-          echo '                  <tr><td colspan="5" class="dataTableContent"><b>' . $cInfo_array[$i]['categories_id'] . ' : ' . $cInfo_array[$i]['categories_name'] . "</b></td></tr>\n";
-          echo '                  <tr><td class="dataTableContent">&nbsp;</td><td colspan="4" class="dataTableContent">' . nl2br($cInfo_array[$i]['categories_description']) . "</td></tr>\n";
-          echo '                  <tr><td class="dataTableContent">&nbsp;</td><td colspan="4" class="dataTableContent"><font color="#FF0000">' . $cInfo_array[$i]['categories_keywords'] . "</font></td></tr>\n";
-          echo '                  <tr class="dataTableHeadingRow">' . "\n";
-          echo "                    <td>&nbsp;</td>\n";
-          echo '                    <td class="dataTableHeadingContent" align="center"><small>' . TABLE_HEADING_SUBCATEGORIES . "</small></td>\n";
-          echo '                    <td class="dataTableHeadingContent" align="center"><small>' . TABLE_HEADING_PRODUCTS . "</small></td>\n";
-          echo '                    <td class="dataTableHeadingContent" align="center"><small>' . TABLE_HEADING_DATE_ADDED . "</small></td>\n";
-          echo '                    <td class="dataTableHeadingContent" align="center"><small>' . TABLE_HEADING_LAST_MODIFIED . "</small></td>\n";
-          echo "                 </tr>\n";
-          echo '                  <tr>' . "\n";
-          echo "                    <td>&nbsp;</td>\n";
-          echo '                    <td align="center" class="dataTableContent"><small>' . $cInfo_array[$i]['childs_count'] . "</small></td>\n";
-          echo '                    <td align="center" class="dataTableContent"><small>' . $cInfo_array[$i]['products_count'] . "</small></td>\n";
-          echo '                    <td align="center" class="dataTableContent"><small>' . $cInfo_array[$i]['date_added'] . "</small></td>\n";
-          echo '                    <td align="center" class="dataTableContent"><small>' . $cInfo_array[$i]['last_modified'] . "</small></td>\n";
-          echo "                 </tr>\n";
-          echo "               </table></td>\n";
-          echo '                <td class="dataTableContent" valign="top" align="right"><a href="' . tep_href_link(FILENAME_CATEGORIES_EDIT, 'cPath=' . $cPath . '&cID=' . $cInfo_array[$i]['categories_id'] . '&action=edit_category') . '">' . 
-                                 tep_image_button('button_edit.gif', IMAGE_EDIT) . '</a> <a href="' . tep_href_link(FILENAME_CATEGORIES_EDIT, 'cPath=' . $cPath . '&cID=' . $cInfo_array[$i]['categories_id'] . '&action=delete_category_confirm') . '">' .
-                                 tep_image_button('button_delete.gif', IMAGE_DELETE) . '</a>';
-          echo '<br><a href="' . tep_href_link(FILENAME_CATEGORIES_EDIT, tep_get_path($cInfo_array[$i]['categories_id'])) . '">' . TEXT_GO_TO_SUBCATEGORIES . '</a>';
-          // products_edit.phpϡʰ
-          if (file_exists(FILENAME_PRODUCTS_EDIT)) {
-            echo '<br><a href="' . tep_href_link(FILENAME_PRODUCTS_EDIT, 'action=search&subject=categories_id&value=' . $cInfo_array[$i]['categories_id']) . '">' . TEXT_GO_TO_PRODUCTS . '</a>';
-          }
-          echo "</td>\n";
+          echo '                <td nowrap><b>' . $cInfo_array[$i]['categories_id'] . "</b></td>\n";
+          echo '                <td><a href="' . tep_href_link(FILENAME_CATEGORIES_EDIT, tep_get_path($cInfo_array[$i]['categories_id'])) . '"><b><font size="+1">' . $cInfo_array[$i]['categories_name'] . "</font></b></a></td>\n";
+          echo '                <td>' . "\n";
+          echo '                  <table border="0" width="100%" cellspacing="0" cellpadding="2">' . "\n";
+          echo '                    <tr><td class="dataTableContent">' . TABLE_HEADING_SUBCATEGORIES . '</td><td class="dataTableContent">' . $cInfo_array[$i]['childs_count'] . '</td><td><a href="' . tep_href_link(FILENAME_CATEGORIES_EDIT, tep_get_path($cInfo_array[$i]['categories_id'])) . '">' . TEXT_GO_TO_LIST . "</a></td></tr>\n";
+          echo '                    <tr><td class="dataTableContent">' . TABLE_HEADING_PRODUCTS . '</td><td class="dataTableContent">' . $cInfo_array[$i]['products_conut'] .'</td><td>' . (file_exists(FILENAME_PRODUCTS_EDIT) ? '<a href="' . tep_href_link(FILENAME_PRODUCTS_EDIT, 'action=search&subject=categories_id&value=' . $cInfo_array[$i]['categories_id']) . '">' . TEXT_GO_TO_LIST . '</a>' : "&nbsp;") .  "</td></tr>\n";
+          echo '                  </table>' . "\n";
+          echo "                </td>\n";
+          echo '                <td>' . "\n";
+          echo '                  <table border="0" width="100%" cellspacing="0" cellpadding="2">' . "\n";
+          echo '                    <tr><td valign="top" align="right">' . '<a href="' . tep_href_link(FILENAME_CATEGORIES_EDIT, 'cPath=' . $cPath . '&cID=' . $cInfo_array[$i]['categories_id'] . '&action=edit_category') . '">' . tep_image_button('button_edit.gif', IMAGE_EDIT) . "</a></td></tr>\n";
+          echo '                    <tr><td valign="top" align="right">' . '<a href="' . tep_href_link(FILENAME_CATEGORIES_EDIT, 'cPath=' . $cPath . '&cID=' . $cInfo_array[$i]['categories_id'] . '&action=delete_category_confirm') . '">' . tep_image_button('button_delete.gif', IMAGE_DELETE) . "</a></td></tr>\n";
+          echo '                  </table>' . "\n";
+          echo "                </td>\n";
+          echo '                <td align="right">' . $cInfo_array[$i]['sort_order'] . "</td>\n";
           echo "              </tr>\n";
-          echo '              <tr class="dataTableRow"><td colspan="3" class="dataTableContent"><hr></td></tr>' . "\n";
         }
       } else {
         // ƥ꡼ʤ
         echo '              <tr class="dataTableRow">' . "\n";
-        echo '                <td class="dataTableContent" colspan="3"><b>' . EMPTY_CATEGORY . '</b></td>';
+        echo '                <td class="dataTableContent" colspan="5"><b>' . EMPTY_CATEGORY . '</b></td>';
         echo "              </tr>\n";
       }
 ?>
