@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: orders.php,v 1.1.1.1 2005/06/30 05:03:59 ryu Exp $
+  $Id: orders.php,v 1.2 2006/03/27 04:49:25 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -148,7 +148,8 @@
             $comments .= strip_tags($ot_title) . '  ' . (int)$orders_total['value'] . ' => ' . (int)$ot_new_value . "\n";
         	   $ot_updated = true;
           } else {
-            $ot_text = $orders_total['text'];
+            $ot_text = $currencies->format($orders_total['value'], true, $orders_currency, $orders_currency_value);
+            tep_db_query("update " . TABLE_ORDERS_TOTAL . " set text = '" . tep_db_input($ot_text) . "' where orders_total_id = '" . tep_db_input($otID) . "'");
           }
           if ($ot_updated) {
             tep_db_query("update " . TABLE_ORDERS_TOTAL . " set title = '" . tep_db_input($ot_title) . "', text = '" . tep_db_input($ot_text) . "', value = '" . tep_db_input($ot_new_value) .  "' where orders_total_id = '" . tep_db_input($otID) . "'");
