@@ -2,7 +2,7 @@
 /*
   products_uploader.php
   2004/12/2
-ǽ2005/9/14
+ǽ2006/1/31
 
 ԡͭ²ҥɥ֥졼
 δʿ
@@ -15,6 +15,14 @@ ryuhei@secondbrain.co.jp
   
   require('includes/products_uploader_config.php');
   
+  // μ
+  if ($HTTP_POST_VARS['specify_id']) {
+    $update = array('upfile_mode' => $HTTP_POST_VARS['specify_id']);
+    $ini_data = inifile_setup($update);
+  } else {
+    $ini_data = inifile_setup();
+  }
+  
   if ($HTTP_GET_VARS['action']) {
     switch ($HTTP_GET_VARS['action']) {
       // åץɥƥåףåץɤǧ
@@ -29,7 +37,7 @@ ryuhei@secondbrain.co.jp
             $up_file = fopen($uploadfile['tmp_name'], 'r');
             fwrite($euc_file, $uploadfile['name'] . "\n");			// åץѤ˥ե̾Ͽ
             while (!feof($up_file)) {
-              $upfile_data = fgets($up_file, $upfile_size);
+              $upfile_data = fgets($up_file, $ini_data['upfile_size']);
               if (empty($upfile_data)) {
                 continue;							// ԤɤФ
               }
@@ -37,6 +45,7 @@ ryuhei@secondbrain.co.jp
                 mb_substitute_character(0x3013);				// ̵ʸִ
                 mb_convert_variables("EUC-JP", "SJIS", $upfile_data);	// SJIS͡EUCѴ
               }
+              $upfile_data = rtrim($upfile_data) . "\n";		// MACб auto_detect_line_endings onɬ
               fwrite($euc_file, $upfile_data);					// ե˽񤭽Ф
               $upfile_count++;
             }
@@ -218,7 +227,7 @@ ryuhei@secondbrain.co.jp
           $up_rec_err_count = 0;
           $up_rec_err_array = array();
           while (!feof($up_file)) {
-            $up_rec = fgetcsv($up_file, $upfile_size, $upfile_delimiter);
+            $up_rec = fgetcsv($up_file, $ini_data['upfile_size'], $ini_data['upfile_delimiter']);
             if (empty($up_rec)) {
               continue;								// ԤɤФ
             }
@@ -243,7 +252,7 @@ ryuhei@secondbrain.co.jp
                   $up_rec_err_flg = true;
                   $up_rec_err_count++;
                 	if (is_array($up_rec)) {
-                	  $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], implode($upfile_delimiter, $up_rec), $cfg_data[$i][1], ERROR_UPLOAD_DATA_DOSE_NOT_EXIST);
+                	  $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], implode($ini_data['upfile_delimiter'], $up_rec), $cfg_data[$i][1], ERROR_UPLOAD_DATA_DOSE_NOT_EXIST);
                 	} else {
                 	  $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], $up_rec, $cfg_data[$i][1], ERROR_UPLOAD_DATA_DOSE_NOT_EXIST);
                 	}
@@ -256,18 +265,18 @@ ryuhei@secondbrain.co.jp
                 $up_rec_err_flg = true;
                 $up_rec_err_count++;
                 if (is_array($up_rec)) {
-                  $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], implode($upfile_delimiter, $up_rec), $cfg_data[$i][1], ERROR_UPLOAD_DATA_IS_REQUIRED);
+                  $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], implode($ini_data['upfile_delimiter'], $up_rec), $cfg_data[$i][1], ERROR_UPLOAD_DATA_IS_REQUIRED);
                 } else {
                   $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], $up_rec, $cfg_data[$i][1], ERROR_UPLOAD_DATA_IS_REQUIRED);
                 }
                 continue;
         	     } else {
         	       // ɤ򥭡˻Ѥϡɬܥå򤹤롣
-        	       if (($cfg_data[$i][6] == 'products_model') && (($HTTP_POST_VARS['specify_id'] == 'yes_ignore') || ($HTTP_POST_VARS['specify_id'] == 'yes_replace')) && ($ok_rec[$i] == '')) {
+        	       if (($cfg_data[$i][6] == 'products_model') && (($ini_data['upfile_mode'] == 'yes_ignore') || ($ini_data['upfile_mode'] == 'yes_replace')) && ($ok_rec[$i] == '')) {
                   $up_rec_err_flg = true;
                   $up_rec_err_count++;
                   if (is_array($up_rec)) {
-                    $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], implode($upfile_delimiter, $up_rec), $cfg_data[$i][1], ERROR_UPLOAD_DATA_IS_REQUIRED);
+                    $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], implode($ini_data['upfile_delimiter'], $up_rec), $cfg_data[$i][1], ERROR_UPLOAD_DATA_IS_REQUIRED);
                   } else {
                     $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], $up_rec, $cfg_data[$i][1], ERROR_UPLOAD_DATA_IS_REQUIRED);
                   }
@@ -282,7 +291,7 @@ ryuhei@secondbrain.co.jp
                     $up_rec_err_flg = true;
                     $up_rec_err_count++;
                     if (is_array($up_rec)) {
-                      $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], implode($upfile_delimiter, $up_rec), $cfg_data[$i][1], ERROR_UPLOAD_CATEGORY_DOES_NOT_EXIST . $ok_rec[$i]);
+                      $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], implode($ini_data['upfile_delimiter'], $up_rec), $cfg_data[$i][1], ERROR_UPLOAD_CATEGORY_DOES_NOT_EXIST . $ok_rec[$i]);
                     } else {
                       $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], $up_rec, $cfg_data[$i][1], ERROR_UPLOAD_CATEGORY_DOES_NOT_EXIST . $ok_rec[$i]);
                     }
@@ -296,7 +305,7 @@ ryuhei@secondbrain.co.jp
                     $up_rec_err_flg = true;
                     $up_rec_err_count++;
                     if (is_array($up_rec)) {
-                      $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], implode($upfile_delimiter, $up_rec), $cfg_data[$i][1], ERROR_UPLOAD_CATEGORY_DOES_NOT_EXIST . $ok_rec[$i]);
+                      $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], implode($ini_data['upfile_delimiter'], $up_rec), $cfg_data[$i][1], ERROR_UPLOAD_CATEGORY_DOES_NOT_EXIST . $ok_rec[$i]);
                     } else {
                       $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], $up_rec, $cfg_data[$i][1], ERROR_UPLOAD_CATEGORY_DOES_NOT_EXIST . $ok_rec[$i]);
                     }
@@ -310,7 +319,7 @@ ryuhei@secondbrain.co.jp
                     $up_rec_err_flg = true;
                     $up_rec_err_count++;
                     if (is_array($up_rec)) {
-                      $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], implode($upfile_delimiter, $up_rec), $cfg_data[$i][1], ERROR_UPLOAD_MANUFACTURER_DOES_NOT_EXIST . $ok_rec[$i]);
+                      $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], implode($ini_data['upfile_delimiter'], $up_rec), $cfg_data[$i][1], ERROR_UPLOAD_MANUFACTURER_DOES_NOT_EXIST . $ok_rec[$i]);
                     } else {
                       $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], $up_rec, $cfg_data[$i][1], ERROR_UPLOAD_MANUFACTURER_DOES_NOT_EXIST . $ok_rec[$i]);
                     }
@@ -324,7 +333,7 @@ ryuhei@secondbrain.co.jp
                     $up_rec_err_flg = true;
                     $up_rec_err_count++;
                     if (is_array($up_rec)) {
-                      $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], implode($upfile_delimiter, $up_rec), $cfg_data[$i][1], ERROR_UPLOAD_MANUFACTURER_DOES_NOT_EXIST . $ok_rec[$i]);
+                      $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], implode($ini_data['upfile_delimiter'], $up_rec), $cfg_data[$i][1], ERROR_UPLOAD_MANUFACTURER_DOES_NOT_EXIST . $ok_rec[$i]);
                     } else {
                       $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], $up_rec, $cfg_data[$i][1], ERROR_UPLOAD_MANUFACTURER_DOES_NOT_EXIST . $ok_rec[$i]);
                     }
@@ -338,7 +347,7 @@ ryuhei@secondbrain.co.jp
                   $up_rec_err_count++;
                   $short_length = $cfg_data[$i][8] - strlen($ok_rec[$i]);
                   if (is_array($up_rec)) {
-                    $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], implode($upfile_delimiter, $up_rec), $cfg_data[$i][1], ERROR_UPLOAD_DATA_IS_SHORTAGE . $short_length);
+                    $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], implode($ini_data['upfile_delimiter'], $up_rec), $cfg_data[$i][1], ERROR_UPLOAD_DATA_IS_SHORTAGE . $short_length);
                   } else {
                     $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], $up_rec, $cfg_data[$i][1], ERROR_UPLOAD_DATA_IS_SHORTAGE . $short_length);
                   }
@@ -348,7 +357,7 @@ ryuhei@secondbrain.co.jp
                   $up_rec_err_count++;
                   $over_length = strlen($ok_rec[$i]) - $cfg_data[$i][9];
                   if (is_array($up_rec)) {
-                    $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], implode($upfile_delimiter, $up_rec), $cfg_data[$i][1], ERROR_UPLOAD_DATA_IS_OVERFLOW . $over_length);
+                    $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], implode($ini_data['upfile_delimiter'], $up_rec), $cfg_data[$i][1], ERROR_UPLOAD_DATA_IS_OVERFLOW . $over_length);
                   } else {
                     $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], $up_rec, $cfg_data[$i][1], ERROR_UPLOAD_DATA_IS_OVERFLOW . $over_length);
                   }
@@ -357,7 +366,7 @@ ryuhei@secondbrain.co.jp
                   $up_rec_err_flg = true;
                   $up_rec_err_count++;
                   if (is_array($up_rec)) {
-                    $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], implode($upfile_delimiter, $up_rec), $cfg_data[$i][1], ERROR_UPLOAD_DATA_IS_NOT_NUMERIC . $ok_rec[$i]);
+                    $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], implode($ini_data['upfile_delimiter'], $up_rec), $cfg_data[$i][1], ERROR_UPLOAD_DATA_IS_NOT_NUMERIC . $ok_rec[$i]);
                   } else {
                     $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], $up_rec, $cfg_data[$i][1], ERROR_UPLOAD_DATA_IS_NOT_NUMERIC . $ok_rec[$i]);
                   }
@@ -367,7 +376,7 @@ ryuhei@secondbrain.co.jp
                     $up_rec_err_flg = true;
                     $up_rec_err_count++;
                     if (is_array($up_rec)) {
-                      $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], implode($upfile_delimiter, $up_rec), $cfg_data[$i][1], ERROR_UPLOAD_DATA_IS_NOT_DATE . $ok_rec[$i]);
+                      $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], implode($ini_data['upfile_delimiter'], $up_rec), $cfg_data[$i][1], ERROR_UPLOAD_DATA_IS_NOT_DATE . $ok_rec[$i]);
                     } else {
                       $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], $up_rec, $cfg_data[$i][1], ERROR_UPLOAD_DATA_IS_NOT_DATE . $ok_rec[$i]);
                     }
@@ -377,7 +386,7 @@ ryuhei@secondbrain.co.jp
               }
             }
             if (!$up_rec_err_flg) {
-              $ok_data = "\n" . implode($upfile_delimiter, $ok_rec);			// ܤ˥åץѥե̾ǼƤΤǡԤ˥åȤ롣
+              $ok_data = "\n" . implode($ini_data['upfile_delimiter'], $ok_rec);			// ܤ˥åץѥե̾ǼƤΤǡԤ˥åȤ롣
               fwrite($ok_file, $ok_data);
               $up_rec_ok_count++;
             }
@@ -426,11 +435,11 @@ ryuhei@secondbrain.co.jp
           $up_file = fopen(FILENAME_UPLOAD_TEMPFILE02, 'r');
           $upload_filename = trim(fgets($up_file, 100));
           while (!feof($up_file)) {
-            $up_rec = fgetcsv($up_file, $upfile_size, $upfile_delimiter);
+            $up_rec = fgetcsv($up_file, $ini_data['upfile_size'], $ini_data['upfile_delimiter']);
             $up_rec = str_replace("\\n", "\n", $up_rec);
             for ($i = 0, $n = sizeof($cfg_data); $i < $n; $i++) {
               if ($cfg_data[$i][5] == 'products') {
-                if (($cfg_data[$i][6] == 'products_model') && (($HTTP_POST_VARS['specify_id'] == 'yes_ignore') || ($HTTP_POST_VARS['specify_id'] == 'yes_replace'))) {
+                if (($cfg_data[$i][6] == 'products_model') && (($ini_data['upfile_mode'] == 'yes_ignore') || ($ini_data['upfile_mode'] == 'yes_replace'))) {
                 	$specified_id = tep_db_prepare_input($up_rec[$i]);
                 }
                 $p_data_array[$cfg_data[$i][6]] = tep_db_prepare_input($up_rec[$i]);
@@ -440,7 +449,7 @@ ryuhei@secondbrain.co.jp
                 $pd_data_array[$cfg_data[$i][6]] = tep_db_prepare_input($up_rec[$i]);
               }
             }
-            if (($HTTP_POST_VARS['specify_id'] == 'yes_ignore') || ($HTTP_POST_VARS['specify_id'] == 'yes_replace')) {
+            if (($ini_data['upfile_mode'] == 'yes_ignore') || ($ini_data['upfile_mode'] == 'yes_replace')) {
               // ޤƱΥǡʤ
               if (tep_db_num_rows(tep_db_query("select * from " . TABLE_PRODUCTS . " where products_id = '" . $specified_id . "'")) == 0) {
                 // yes_ignoreyes_replaceȤinsert
@@ -461,7 +470,7 @@ ryuhei@secondbrain.co.jp
                 $insert_ok_count++;
               } else {
                 // ƱΥǡ
-                if ($HTTP_POST_VARS['specify_id'] == 'yes_replace') {
+                if ($ini_data['upfile_mode'] == 'yes_replace') {
                   // yes_replaceξϡ¸ΥǡdeleteƤinsertyes_ignoreξϤʤˤ⤷ʤ
                   // productsơ֥ؤι
                   $update_p_data = array('products_date_added' => $upload_date);
@@ -478,7 +487,7 @@ ryuhei@secondbrain.co.jp
                 }
               }
             } else {
-              // noξϤΤޤinsert
+              // no_useξϤΤޤinsert
               // productsơ֥ؤϿ
               $insert_p_data = array('products_date_added' => $upload_date);
               $sql_data_array = tep_array_merge($p_data_array, $insert_p_data);
@@ -707,16 +716,16 @@ ryuhei@secondbrain.co.jp
           for ($i = 1, $csv_count_max; $i <= $csv_count_max; $i++) {
             if (isset($column_list[$i])) {
               if (($column_list[$i] == 'categories_id') && ($cname_flg)) {
-                $csv_rec .= ($csv_row_flg ? $upfile_delimiter . '"' : '"') . $categories_id_array[$download[$column_list[$i]]] . '"';
+                $csv_rec .= ($csv_row_flg ? $ini_data['upfile_delimiter'] . '"' : '"') . $categories_id_array[$download[$column_list[$i]]] . '"';
               } elseif (($column_list[$i] == 'manufacturers_id') && ($mname_flg)) {
-                $csv_rec .= ($csv_row_flg ? $upfile_delimiter . '"' : '"') . $manufacturers_id_array[$download[$column_list[$i]]] . '"';
+                $csv_rec .= ($csv_row_flg ? $ini_data['upfile_delimiter'] . '"' : '"') . $manufacturers_id_array[$download[$column_list[$i]]] . '"';
               } elseif (($column_list[$i] == 'products_price')) {
-                $csv_rec .= ($csv_row_flg ? $upfile_delimiter . '"' : '"') . (int)$download[$column_list[$i]] . '"';
+                $csv_rec .= ($csv_row_flg ? $ini_data['upfile_delimiter'] . '"' : '"') . (int)$download[$column_list[$i]] . '"';
               } else {
-                $csv_rec .= ($csv_row_flg ? $upfile_delimiter . '"' : '"') . $download[$column_list[$i]] . '"';
+                $csv_rec .= ($csv_row_flg ? $ini_data['upfile_delimiter'] . '"' : '"') . $download[$column_list[$i]] . '"';
               }
             } else {
-              $csv_rec .= ($csv_rec ? $upfile_delimiter : '');
+              $csv_rec .= ($csv_rec ? $ini_data['upfile_delimiter'] : '');
             }
             $csv_row_flg = true;
           }
@@ -1074,7 +1083,31 @@ switch ($HTTP_GET_VARS['action']) {
         </td>
       </tr>
       <tr><td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td></tr>
-      <tr><td class="main"><?php echo TEXT_USE_PRODUCTS_MODEL_AS_ID . '&nbsp;&nbsp;' . tep_draw_radio_field('specify_id', 'yes_ignore', true) . '&nbsp;' . TEXT_USE_PRODUCTS_MODEL_YES_IGNORE . '&nbsp;&nbsp;' . tep_draw_radio_field('specify_id', 'yes_replace') . '&nbsp;' . TEXT_USE_PRODUCTS_MODEL_YES_REPLACE . '&nbsp;&nbsp;' . tep_draw_radio_field('specify_id', 'no') . '&nbsp;' . TEXT_USE_PRODUCTS_MODEL_NO; ?></td></tr>
+      <tr><td class="main">
+<?php
+        switch ($ini_data['upfile_mode']) {
+          case 'no_use':
+            $flg_yes_ignore = false;
+            $flg_yes_replace = false;
+            $flg_no = true;
+            break;
+          case 'yes_replace':
+            $flg_yes_ignore = false;
+            $flg_yes_replace = true;
+            $flg_no = false;
+            break;
+          case 'yes_ignore':
+          default:
+            $flg_yes_ignore = true;
+            $flg_yes_replace = false;
+            $flg_no = false;
+            break;
+        }
+        echo TEXT_USE_PRODUCTS_MODEL_AS_ID . '&nbsp;&nbsp;';
+        echo tep_draw_radio_field('specify_id', 'yes_ignore', $flg_yes_ignore) . '&nbsp;' . TEXT_USE_PRODUCTS_MODEL_YES_IGNORE . '&nbsp;&nbsp;';
+        echo tep_draw_radio_field('specify_id', 'yes_replace', $flg_yes_replace) . '&nbsp;' . TEXT_USE_PRODUCTS_MODEL_YES_REPLACE . '&nbsp;&nbsp;';
+        echo tep_draw_radio_field('specify_id', 'no_use', $flg_no) . '&nbsp;' . TEXT_USE_PRODUCTS_MODEL_NO;
+?></td></tr>
       <tr><td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td></tr>
       <tr>
         <td width="100%" class="main"><?php echo tep_image_submit('button_confirm.gif', IMAGE_CONFIRM) . ' <a href="' . tep_href_link(FILENAME_PRODUCTS_UPLOADER) . '">' . tep_image_button('button_back.gif', IMAGE_BACK) . '</a>'; ?>
@@ -1164,7 +1197,7 @@ switch ($HTTP_GET_VARS['action']) {
     } else {
 ?>
       <tr><td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td></tr>
-      <tr><?php echo tep_draw_form('upload', FILENAME_PRODUCTS_UPLOADER, 'action=upload') . tep_draw_hidden_field("language_id", $HTTP_POST_VARS['language_id']) . tep_draw_hidden_field("specify_id", $HTTP_POST_VARS['specify_id']); ?>
+      <tr><?php echo tep_draw_form('upload', FILENAME_PRODUCTS_UPLOADER, 'action=upload') . tep_draw_hidden_field("language_id", $HTTP_POST_VARS['language_id']); ?>
         <td width="100%" class="main"><?php echo tep_image_submit('button_upload.gif', IMAGE_UPLOAD) . ' <a href="' . tep_href_link(FILENAME_PRODUCTS_UPLOADER) . '">' . tep_image_button('button_back.gif', IMAGE_BACK) . '</a>'; ?>
         </td>
       </form></tr>
