@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: account.php,v 1.3 2006/02/03 07:38:01 ryu Exp $
+  $Id: account.php,v 1.4 2006/03/23 02:12:25 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -15,6 +15,10 @@
 
   require('includes/application_top.php');
 
+  if (defined("KN_CFG_ALLOW_CHECKOUT") && (KN_CFG_ALLOW_CHECKOUT == "false")) {
+    tep_redirect(tep_href_link(FILENAME_DEFAULT));
+  }
+
   if (!tep_session_is_registered('customer_id')) {
     $navigation->set_snapshot();
     tep_redirect(tep_href_link(FILENAME_LOGIN, '', 'SSL'));
