@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: checkout_process.php,v 1.3 2006/02/01 07:11:50 ryu Exp $
+  $Id: checkout_process.php,v 1.5 2006/03/27 10:11:39 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -15,6 +15,10 @@
 
   include('includes/application_top.php');
 
+  if (defined("KN_CFG_ALLOW_CHECKOUT") && (KN_CFG_ALLOW_CHECKOUT == "false")) {
+    tep_redirect(tep_href_link(FILENAME_DEFAULT));
+  }
+
 // ̾ǤȴʰǤ̤Ѥ
   if (KN_CFG_SHORT_CHECKOUT == 'true') {
   // if the customer is not logged on, redirect them to the login page
@@ -353,7 +357,7 @@
                     EMAIL_SEPARATOR . "\n" .
                     tep_address_label($customer_id, $billto, 0, '', "\n") . "\n";
 
-    if (is_object($$payment)) {
+    if ((KN_CFG_SHORT_CHECKOUT == 'false') && (is_object($$payment))) {
       $email_order .= EMAIL_TEXT_PAYMENT_METHOD . "\n" . 
                       EMAIL_SEPARATOR . "\n";
       $payment_class = $$payment;
