@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: checkout_shipping_address.php,v 1.2 2005/08/19 09:48:12 ryu Exp $
+  $Id: checkout_shipping_address.php,v 1.3 2006/03/23 02:12:25 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -15,6 +15,10 @@
 
   require('includes/application_top.php');
 
+  if (defined("KN_CFG_ALLOW_CHECKOUT") && (KN_CFG_ALLOW_CHECKOUT == "false")) {
+    tep_redirect(tep_href_link(FILENAME_DEFAULT));
+  }
+
 // if the customer is not logged on, redirect them to the login page
   if (!tep_session_is_registered('customer_id')) {
     $navigation->set_snapshot();
