@@ -1,18 +1,24 @@
 <?php
 /*
-  checkout_shipping_address_short.php
-  2004/12/2
-ǽ2005/8/19
+  $Id: checkout_shipping_address_short.php,v 1.3 2006/03/23 02:12:25 ryu Exp $
 
-ԡͭ²ҥɥ֥졼
-δʿ
-ryuhei@secondbrain.co.jp
+  osCommerce, Open Source E-Commerce Solutions
+  http://www.oscommerce.com
+
+  Copyright (c) 2003 osCommerce
 
   Released under the GNU General Public License
+  
+  modified for Koshoten.net2
+  http://www.koshoten.net/
 */
 
   require('includes/application_top.php');
 
+  if (defined("KN_CFG_ALLOW_CHECKOUT") && (KN_CFG_ALLOW_CHECKOUT == "false")) {
+    tep_redirect(tep_href_link(FILENAME_DEFAULT));
+  }
+
 // if the customer is not logged on, redirect them to the login page
   if (!tep_session_is_registered('customer_id')) {
     $navigation->set_snapshot();
