@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: create_account.php,v 1.3 2006/01/29 14:49:22 ryu Exp $
+  $Id: create_account.php,v 1.4 2006/03/23 02:12:25 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -15,6 +15,10 @@
 
   require('includes/application_top.php');
 
+  if (defined("KN_CFG_ALLOW_CHECKOUT") && (KN_CFG_ALLOW_CHECKOUT == "false")) {
+    tep_redirect(tep_href_link(FILENAME_DEFAULT));
+  }
+
   require(DIR_WS_LANGUAGES . $language . '/' . FILENAME_CREATE_ACCOUNT);
 
   $breadcrumb->add(NAVBAR_TITLE, tep_href_link(FILENAME_CREATE_ACCOUNT));
