@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: information.php,v 1.1.1.1 2005/06/30 05:04:14 ryu Exp $
+  $Id: information.php,v 1.2 2006/03/23 02:12:26 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -24,8 +24,10 @@
     while($box_shop_info = tep_db_fetch_array($box_shop_info_query)) {
       $infobox_contents[] = array('text' => '<a href="' . tep_href_link(FILENAME_INFORMATION, 'siID=' . $box_shop_info['shop_info_id']) . '">' . $box_shop_info['shop_info_title'] . '</a><br>');
     }
-
+  if (defined("KN_CFG_CONTACT_BY_EMAIL") && (KN_CFG_CONTACT_BY_EMAIL == 'false')) {
+  } else {
     $infobox_contents[] = array('text' => '<a href="' . tep_href_link(FILENAME_CONTACT_US) . '">' . BOX_INFORMATION_CONTACT . '</a>');
+  }
 
     new infoBox($cssid, $infobox_contents, $infobox_header);
   }
