@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: products_new.php,v 1.2 2005/10/06 09:50:37 ryu Exp $
+  $Id: products_new.php,v 1.3 2006/03/23 02:12:26 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -21,10 +21,23 @@
 <?php
   } else {
     for($i=0, $n=sizeof($products_new_array); $i<$n; $i++) {
-      if (isset($products_new_array[$i]['specials_price'])) {
-        $products_price = '<s>' .  $currencies->display_price($products_new_array[$i]['price'], tep_get_tax_rate($products_new_array[$i]['tax_class_id'])) . '</s>&nbsp;&nbsp;<span class="productSpecialPrice">' . $currencies->display_price($products_new_array[$i]['specials_price'], tep_get_tax_rate($products_new_array[$i]['tax_class_id'])) . '</span>';
+      if ((KN_CFG_CONTACT_PRICE != 0) && ($products_new_array[$i]['price'] == KN_CFG_CONTACT_PRICE)) {
+        if (defined("KN_CFG_CONTACT_BY_EMAIL") && (KN_CFG_CONTACT_BY_EMAIL == 'false')) {
+          $products_price = KN_CFG_CONTACT_PRICE_TEXT;
+        } else {
+          $sjis_p_name = mb_convert_encoding($products_new_array[$i]['name'], "SJIS", "EUC-JP");
+          $sjis_p_email_subject = mb_convert_encoding(KN_CFG_CONTACT_PRICE_EMAIL_SUBJECT, "SJIS", "EUC-JP");
+          $sjis_p_email_body = mb_convert_encoding(KN_CFG_CONTACT_PRICE_EMAIL_BODY, "SJIS", "EUC-JP");
+          $email_subject = rawurlencode($sjis_p_email_subject) . rawurlencode($sjis_p_name);
+          $email_body = rawurlencode($sjis_p_email_body);
+          $products_price = '<a href="mailto:' . STORE_OWNER_EMAIL_ADDRESS . '?subject=' . $email_subject . '&body=' . $email_body . '">' . KN_CFG_CONTACT_PRICE_TEXT . '</a>';
+        }
       } else {
-        $products_price = $currencies->display_price($products_new_array[$i]['price'], tep_get_tax_rate($products_new_array[$i]['tax_class_id']));
+        if (isset($products_new_array[$i]['specials_price'])) {
+          $products_price = '<s>' .  $currencies->display_price($products_new_array[$i]['price'], tep_get_tax_rate($products_new_array[$i]['tax_class_id'])) . '</s>&nbsp;&nbsp;<span class="productSpecialPrice">' . $currencies->display_price($products_new_array[$i]['specials_price'], tep_get_tax_rate($products_new_array[$i]['tax_class_id'])) . '</span>';
+        } else {
+          $products_price = $currencies->display_price($products_new_array[$i]['price'], tep_get_tax_rate($products_new_array[$i]['tax_class_id']));
+        }
       }
       echo '<table class="productsNewProduct">' . "\n";
       echo '<tr><td>' . "\n";
@@ -42,7 +55,10 @@
       echo (KN_CFG_USE_PUBLISHED == 'true' ? '<span class="pPublished">' . $products_new_array[$i]['published'] . '</span> ' : '');
       echo '<span class="pDescription">' . $products_new_array[$i]['products_description'] . '</span></div>';
       echo '<div class="productsNewPrice"><span class="pPrice">' . $products_price . '<span></div>' . "\n";
-      echo '<div class="productsNewBuyNow"><a href="' . tep_href_link(FILENAME_PRODUCTS_NEW, tep_get_all_get_params(array('action')) . 'action=buy_now&products_id=' . $products_new_array[$i]['id']) . '">' . tep_image_button('button_in_cart.gif', IMAGE_BUTTON_IN_CART) . '</a></div>' . "\n";
+      if (defined("KN_CFG_ALLOW_CHECKOUT") && (KN_CFG_ALLOW_CHECKOUT == "false")) {
+      } else {
+        echo '<div class="productsNewBuyNow"><a href="' . tep_href_link(FILENAME_PRODUCTS_NEW, tep_get_all_get_params(array('action')) . 'action=buy_now&products_id=' . $products_new_array[$i]['id']) . '">' . tep_image_button('button_in_cart.gif', IMAGE_BUTTON_IN_CART) . '</a></div>' . "\n";
+      }
       echo '</td>' . "\n";
       echo '</tr>' . "\n";
       echo '</table>' . "\n";
