@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: product_info.php,v 1.3 2005/09/22 01:12:02 ryu Exp $
+  $Id: product_info.php,v 1.5 2006/03/27 06:05:35 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -17,7 +17,10 @@
 
   require(DIR_WS_LANGUAGES . $language . '/' . FILENAME_PRODUCT_INFO);
 
-  $product_info_query = tep_db_query("select p.products_id, pd.products_name, pd.products_subtitle, pd.products_series_title, pd.products_author, pd.products_published, pd.products_publishers, pd.products_volume, p.products_isbn, pd.products_description, pd.products_description2, p.products_model, p.products_quantity, p.products_image, pd.products_url, p.products_price, p.products_tax_class_id, p.products_date_added, p.products_date_available, p.manufacturers_id from " . TABLE_PRODUCTS . " p, " . TABLE_PRODUCTS_DESCRIPTION . " pd where p.products_status = '1' and p.products_id = '" . (int)$HTTP_GET_VARS['products_id'] . "' and pd.products_id = p.products_id and pd.language_id = '" . $languages_id . "'");
+  $please_contact_us = false;
+  $meta_discription = '';
+  $meta_keywords = '';
+  $product_info_query = tep_db_query("select p.products_id, pd.products_name, pd.products_subtitle, pd.products_series_title, pd.products_author, pd.products_published, pd.products_publishers, pd.products_volume, p.products_isbn, pd.products_description, pd.products_description2, pd.products_keywords, p.products_model, p.products_quantity, p.products_image, pd.products_url, p.products_price, p.products_tax_class_id, p.products_date_added, p.products_date_available, p.manufacturers_id from " . TABLE_PRODUCTS . " p, " . TABLE_PRODUCTS_DESCRIPTION . " pd where p.products_status = '1' and p.products_id = '" . (int)$HTTP_GET_VARS['products_id'] . "' and pd.products_id = p.products_id and pd.language_id = '" . $languages_id . "'");
   if (!tep_db_num_rows($product_info_query)) { // product not found in database
     $no_product_info = true;
     $product_info_title = TITLE;
@@ -25,6 +28,25 @@
     $no_product_info = false;
     $product_info = tep_db_fetch_array($product_info_query);
     $product_info_title = TITLE . ' : ' . $product_info['products_name'];
+    if ($product_info['products_description2']) {
+      if (mb_strlen($product_info['products_description2']) > 200) {
+        $meta_products_description2 = mb_substr(@strip_tags($product_info['products_description2']), 0, 200);
+      } else {
+        $meta_products_description2 = @strip_tags($product_info['products_description2']);
+      }
+      $meta_description = '<meta name="Description" content="' . $meta_products_description2 . '">' . "\n";
+    }
+    if ($product_info['products_keywords']) {
+      $meta_keywords = '<meta name="Keywords" content="' . implode(",", explode(" ", $product_info['products_keywords'])) . '">' . "\n";
+    }
+    if ((KN_CFG_CONTACT_PRICE != 0) && ($product_info['products_price'] == KN_CFG_CONTACT_PRICE)) {
+      $please_contact_us = true;
+      $sjis_p_name = mb_convert_encoding($product_info['products_name'], "SJIS", "EUC-JP");
+      $sjis_p_email_subject = mb_convert_encoding(KN_CFG_CONTACT_PRICE_EMAIL_SUBJECT, "SJIS", "EUC-JP");
+      $sjis_p_email_body = mb_convert_encoding(KN_CFG_CONTACT_PRICE_EMAIL_BODY, "SJIS", "EUC-JP");
+      $email_subject = rawurlencode($sjis_p_email_subject) . rawurlencode($sjis_p_name);
+      $email_body = rawurlencode($sjis_p_email_body);
+    }
   }
 ?>
 <!doctype html public "-//W3C//DTD HTML 4.01 Transitional//EN">
@@ -32,6 +54,7 @@
 <head>
 <meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>">
 <title><?php echo $product_info_title; ?></title>
+<?php echo $meta_description . $meta_keywords; ?>
 <base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>">
 <link rel="stylesheet" type="text/css" href="general.css">
 <link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_PRODUCT_INFO, 0, strrpos(FILENAME_PRODUCT_INFO, '.'));?>.css">
@@ -160,10 +183,18 @@ document.write('<?php echo '<a href="javascript:popupWindow(\\\'' . tep_href_lin
       echo '      <div class="pModel"><span class="pInfoHeading">' . TEXT_PRODUCTS_MODEL . '</span>' . $product_info['products_model'] . '</div>' . "\n";
     }
 
-    if ($new_price = tep_get_products_special_price($product_info['products_id'])) {
-      echo '      <div class="pPrice"><span class="pInfoHeading">' . TEXT_PRODUCTS_PRICE . '</span><s>' . $currencies->display_price($product_info['products_price'], tep_get_tax_rate($product_info['products_tax_class_id'])) . '</s> <span class="pSpecialPrice">' . $currencies->display_price($new_price, tep_get_tax_rate($product_info['products_tax_class_id'])) . '</span></div>' . "\n";
+    if ($please_contact_us) {
+      if (defined("KN_CFG_CONTACT_BY_EMAIL") && (KN_CFG_CONTACT_BY_EMAIL == 'false')) {
+        echo '      <div class="pPrice">' . KN_CFG_CONTACT_PRICE_TEXT . '</div>' . "\n";
+      } else {
+        echo '      <div class="pPrice"><a href="mailto:' . STORE_OWNER_EMAIL_ADDRESS . '?subject=' . $email_subject . '&body=' . $email_body . '">' . KN_CFG_CONTACT_PRICE_TEXT . '</a></div>' . "\n";
+      }
     } else {
-      echo '      <div class="pPrice"><span class="pInfoHeading">' . TEXT_PRODUCTS_PRICE . '</span>' . $currencies->display_price($product_info['products_price'], tep_get_tax_rate($product_info['products_tax_class_id'])) . '</div>' . "\n";
+      if ($new_price = tep_get_products_special_price($product_info['products_id'])) {
+        echo '      <div class="pPrice"><span class="pInfoHeading">' . TEXT_PRODUCTS_PRICE . '</span><s>' . $currencies->display_price($product_info['products_price'], tep_get_tax_rate($product_info['products_tax_class_id'])) . '</s> <span class="pSpecialPrice">' . $currencies->display_price($new_price, tep_get_tax_rate($product_info['products_tax_class_id'])) . '</span></div>' . "\n";
+      } else {
+        echo '      <div class="pPrice"><span class="pInfoHeading">' . TEXT_PRODUCTS_PRICE . '</span>' . $currencies->display_price($product_info['products_price'], tep_get_tax_rate($product_info['products_tax_class_id'])) . '</div>' . "\n";
+      }
     }
 ?>
       <table>
@@ -178,8 +209,22 @@ document.write('<?php echo '<a href="javascript:popupWindow(\\\'' . tep_href_lin
 <?php
       }
     }
+    if (defined("KN_CFG_ALLOW_CHECKOUT") && (KN_CFG_ALLOW_CHECKOUT == "false")) {
+?>
+          <td class="buttonRight"></td>
+<?php
+    } else {
+      if ($please_contact_us) {
+?>
+          <td class="buttonRight"></td>
+<?php
+      } else {
 ?>
           <td class="buttonRight"><?php echo tep_draw_hidden_field('products_id', $product_info['products_id']) . tep_image_submit('button_in_cart.gif', IMAGE_BUTTON_IN_CART); ?></td>
+<?php
+      }
+    }
+?>
         </tr>
       </table>
 <?php
